==================
README for HydraTK
==================

| HydraTK (Hydra Toolkit) is fully extendable object oriented application toolkit with nice modular architecture. 
| It's useful mainly for creating utilities for system analysis and general testing.
| It has decent portfolio of features:

* nice commandline interface
* extension interface
* events and functionality hooks
* services
* messaging
* parallel processing
* internalization support


OS and Python versions support
==============================

| Currently the Linux platform with CPython 2.6, 2.7, 3.3, 3.4, 3.5, 3.6, PyPy 2.7 is supported, 
| but the final version is planned to be crossplatform and targeted also to the other popular systems 
| including Windows and MacOS and possibly other Python versions such as Jython and IronPython